##  Changes Introduced with the Extension
Item | Applied Changes
---|---
Application fact sheet |  New fact sheet subtypes:
  * [AI agent](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model?locale=en-US&state=PRODUCTION&version=CLOUD#loio9e7a0401e05c4c38abaee265bb3f7390__section_utt_sd4_2hc) subtype with dedicated attributes
  * [Business application](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model?locale=en-US&state=PRODUCTION&version=CLOUD#loio9e7a0401e05c4c38abaee265bb3f7390__section_nhn_td4_2hc) subtype with dedicated attributes

To learn how activating the extension affects existing application subtypes, see [Scenarios for Application Subtypes](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model?locale=en-US&state=PRODUCTION&version=CLOUD#loio9e7a0401e05c4c38abaee265bb3f7390__section_m4l_sd4_2hc).
Interface fact sheet |
  * New fact sheet subtype [MCP server](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model?locale=en-US&state=PRODUCTION&version=CLOUD#loio9e7a0401e05c4c38abaee265bb3f7390__section_apr_td4_2hc) with dedicated attributes
  * New attributes on the [API](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model?locale=en-US&state=PRODUCTION&version=CLOUD#loio9e7a0401e05c4c38abaee265bb3f7390__section_n1w_td4_2hc) fact sheet subtype


Reports | The AI Agents  collection with dedicated reports is added. For details, see [Reports for AI Agents](https://help.sap.com/docs/leanix/ea/reports-for-ai-agents?locale=en-US&state=PRODUCTION&version=CLOUD "Use reports to get an overview of AI agents in your enterprise architecture landscape.").
KPIs |  KPIs for AI agents are added to the architecture executive dashboard:
  * Agents portfolio
  * Approved agents
  * Agents quality seal
  * Risk reduction
  * Cost saving
  * Revenue increase


Saved searches |  Dedicated saved searches are added to the inventory:
  * AI agents overview
  * AI agent governance
  * AI agents consuming MCP servers
  * MCP server enabled business applications


Calculations | Calculations for computing the business value of AI agents are activated. For details, see [Calculations for AI Agents](https://help.sap.com/docs/leanix/ea/calculations-for-ai-agents?locale=en-US&state=PRODUCTION&version=CLOUD "Automatically calculate the business value of your AI agents.").


